@@ -92,7 +92,7 @@ def main() -> None:
                         default=[], help="file extensions to parse.")
     parser.add_argument("--print-token-tree", "-ptt", nargs='?', required=False,
                         const=True, default=False, help="print AST plus corresponding Tokens")
-    parser.add_argument("--output-style", "-out", choices=['stdErr', 'json'], required=False,
+    parser.add_argument("--output-style", "-out", choices=['stdErr', 'json', 'sonarqube'], required=False,
                         default='stdErr', help="file extensions to parse.")
     parser.add_argument("--find-config", "-fcfg", nargs='?', required=False,
                         const=True, default=False,
@@ -103,7 +103,6 @@ def main() -> None:
 
     baseDir = Path(args.files[0]) if os.path.isdir(args.files[0]) else Path(args.files[0]).parent()
     args = readConfig(args)
-    print(baseDir)
     clang_args = args.args
 
     if args.argfile is not None:
@@ -155,6 +154,8 @@ def main() -> None:
         out.printError()
     if args.output_style == "json":
         out.printJson()
+    if args.output_style == "sonarqube":
+        out.printSonarqube()
 
 
 if __name__ == "__main__":
